@@ -34,7 +34,7 @@ class SecretScan:
         file_path_findings = ""
         secret_external_checks=dict_args["token_external_checks"]
         if skip_tool == False:
-            self.tool_gateway.install_tool(self.devops_platform_gateway.get_variable("os"), self.devops_platform_gateway.get_variable("temp_directory"))
+            self.tool_gateway.install_tool(self.devops_platform_gateway.get_variable("os"), self.devops_platform_gateway.get_variable("temp_directory"), config_tool.tool_version)
             files_pullrequest = self.git_gateway.get_files_pull_request(
                 self.devops_platform_gateway.get_variable("path_directory"),
                 self.devops_platform_gateway.get_variable("target_branch"),
@@ -52,7 +52,8 @@ class SecretScan:
                     self.devops_platform_gateway.get_variable("repository"),
                     config_tool,
                     secret_tool,
-                    secret_external_checks)
+                    secret_external_checks,
+                    self.devops_platform_gateway.get_variable("temp_directory"))
             finding_list = self.tool_deserialize.get_list_vulnerability(
                 findings,
                 self.devops_platform_gateway.get_variable("os"),
